==> haskell-persistent-sqlite-2.13.1.1-30-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-BPK5PZ8Wkir1XmVcU1KeCL
key:                    persistent-sqlite-2.13.1.1-BPK5PZ8Wkir1XmVcU1KeCL
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    f3d57d49b83dfbfb3aaaeb2a3eb918d5
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-BPK5PZ8Wkir1XmVcU1KeCL
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    containers-0.6.7 microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW mtl-2.2.2
    persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
    resource-pool-0.2.3.2-5oQsv6yyKmlCMdNDJD8QG7
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.1.1-52-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-K1kk574y6hi2PB9vtIDOe1
key:                    persistent-sqlite-2.13.1.1-K1kk574y6hi2PB9vtIDOe1
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    e39bd6639c68105ff9789d84aee9ff14
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-K1kk574y6hi2PB9vtIDOe1
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    containers-0.6.7 microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG mtl-2.2.2
    persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
    resource-pool-0.2.3.2-IwokjjpbTKCEUx26uJ9tBR
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
